==> openGion6.8.6.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE12S.sql <==
/****************************************************************************/
/* GE12 ( ｼｽﾃﾑﾊﾟﾗﾒｰﾀ定義 )                                                  */
/*                                                                          */
/* Created : 2017/07/18 08:42:11                                            */
/****************************************************************************/

CREATE TABLE GE12 (
   SYSTEM_ID    varchar           (   10 )                      NOT NULL            /*  10 ｼｽﾃﾑID       */
 , PARAM_ID     varchar           (   50 )                      NOT NULL            /*  20 ﾊﾟﾗﾒｰﾀID     */
 , SEQNO        INTEGER                         DEFAULT 0       NOT NULL            /*  30 表示順       */
 , TITLE        varchar           (  300 )                                          /*  40 ﾀｲﾄﾙ         */
 , PARAM        varchar           (  500 )                                          /*  50 設定値       */
 , CONTENTS     varchar           ( 4000 )                                          /*  60 内容         */
 , PARAM_LVL    varchar           (    1 )      DEFAULT '5'     NOT NULL            /*  70 設定ﾚﾍﾞﾙ     */
 , KBSAKU       varchar           (    1 )      DEFAULT '1'     NOT NULL            /*  80 作成区分     */
 , FGCRYPT      varchar           (    1 )      DEFAULT '0'     NOT NULL            /*  90 暗号化ﾌﾗｸﾞ   */
 , CONTXT_PATH  varchar           (   50 )      DEFAULT '**'    NOT NULL            /* 100 ｺﾝﾃｷｽﾄﾊﾟｽ    */
 , FGREBOOT     varchar           (    1 )      DEFAULT '0'                         /* 110 要再起動ﾌﾗｸﾞ */
 , UNIQ         int IDENTITY(1,1)                                                   /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT '1'     NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                          /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                          /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                          /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                          /* 850 作成社員     */
 , DYUPD        varchar           (   14 )                                          /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                          /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                          /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                          /* 890 更新者       */
);

==> openGion7.2.0.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE12S.sql <==
/****************************************************************************/
/* GE12 ( ｼｽﾃﾑﾊﾟﾗﾒｰﾀ定義 )                                                  */
/*                                                                          */
/* Created : 2018/09/28 16:03:39                                            */
/****************************************************************************/

CREATE TABLE GE12 (
   SYSTEM_ID    varchar           (   10 )                      NOT NULL            /*  10 ｼｽﾃﾑID       */
 , PARAM_ID     varchar           (   50 )                      NOT NULL            /*  20 ﾊﾟﾗﾒｰﾀID     */
 , SEQNO        INTEGER                         DEFAULT 0       NOT NULL            /*  30 表示順       */
 , TITLE        varchar           (  300 )                                          /*  40 ﾀｲﾄﾙ         */
 , PARAM        varchar           (  500 )                                          /*  50 設定値       */
 , CONTENTS     varchar           ( 4000 )                                          /*  60 内容         */
 , PARAM_LVL    varchar           (    1 )      DEFAULT '5'     NOT NULL            /*  70 設定ﾚﾍﾞﾙ     */
 , KBSAKU       varchar           (    1 )      DEFAULT '1'     NOT NULL            /*  80 作成区分     */
 , FGCRYPT      varchar           (    1 )      DEFAULT '0'     NOT NULL            /*  90 暗号化ﾌﾗｸﾞ   */
 , CONTXT_PATH  varchar           (   50 )      DEFAULT '**'    NOT NULL            /* 100 ｺﾝﾃｷｽﾄﾊﾟｽ    */
 , FGREBOOT     varchar           (    1 )      DEFAULT '0'                         /* 110 要再起動ﾌﾗｸﾞ */
 , UNIQ         int IDENTITY(1,1)                                                   /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT '1'     NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                          /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                          /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                          /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                          /* 850 作成者       */
 , DYUPD        varchar           (   14 )                                          /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                          /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                          /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                          /* 890 更新者       */
);
